* ChangeLog: Follow spelling conventions.
authorkazu <kazu@138bc75d-0d04-0410-961f-82ee72b054a4>
Thu, 12 Jun 2003 19:01:08 +0000 (19:01 +0000)
committerkazu <kazu@138bc75d-0d04-0410-961f-82ee72b054a4>
Thu, 12 Jun 2003 19:01:08 +0000 (19:01 +0000)
* ChangeLog.2: Likewise.
* c-decl.c: Likewise.
* cfgloop.h: Likewise.
* cgraph.c: Likewise.
* coverage.c: Likewise.
* cppcharset.c: Likewise.
* cpphash.h: Likewise.
* cpplex.c: Likewise.
* cpplib.c: Likewise.
* dbxout.c: Likewise.
* df.c: Likewise.
* dwarf2out.c: Likewise.
* dwarfout.c: Likewise.
* emit-rtl.c: Likewise.
* explow.c: Likewise.
* gcov-io.c: Likewise.
* gcov-io.h: Likewise.
* gcov.c: Likewise.
* gengtype.c: Likewise.
* ggc.h: Likewise.
* opts.c: Likewise.
* real.c: Likewise.
* reload.c: Likewise.
* stmt.c: Likewise.

git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@67849 138bc75d-0d04-0410-961f-82ee72b054a4

25 files changed:
gcc/ChangeLog
gcc/ChangeLog.2
gcc/c-decl.c
gcc/cfgloop.h
gcc/cgraph.c
gcc/coverage.c
gcc/cppcharset.c
gcc/cpphash.h
gcc/cpplex.c
gcc/cpplib.c
gcc/dbxout.c
gcc/df.c
gcc/dwarf2out.c
gcc/dwarfout.c
gcc/emit-rtl.c
gcc/explow.c
gcc/gcov-io.c
gcc/gcov-io.h
gcc/gcov.c
gcc/gengtype.c
gcc/ggc.h
gcc/opts.c
gcc/real.c
gcc/reload.c
gcc/stmt.c

index cb819ff..4777c15 100644 (file)
@@ -1,3 +1,31 @@
+2003-06-12  Kazu Hirata  <kazu@cs.umass.edu>
+
+       * ChangeLog: Follow spelling conventions.
+       * ChangeLog.2: Likewise.
+       * c-decl.c: Likewise.
+       * cfgloop.h: Likewise.
+       * cgraph.c: Likewise.
+       * coverage.c: Likewise.
+       * cppcharset.c: Likewise.
+       * cpphash.h: Likewise.
+       * cpplex.c: Likewise.
+       * cpplib.c: Likewise.
+       * dbxout.c: Likewise.
+       * df.c: Likewise.
+       * dwarf2out.c: Likewise.
+       * dwarfout.c: Likewise.
+       * emit-rtl.c: Likewise.
+       * explow.c: Likewise.
+       * gcov-io.c: Likewise.
+       * gcov-io.h: Likewise.
+       * gcov.c: Likewise.
+       * gengtype.c: Likewise.
+       * ggc.h: Likewise.
+       * opts.c: Likewise.
+       * real.c: Likewise.
+       * reload.c: Likewise.
+       * stmt.c: Likewise.
+
 2003-06-12  Janis Johnson  <janis187@us.ibm.com>
 
        * doc/install.texi (m32r-*-elf): Change company to Renesas.
@@ -2420,7 +2448,7 @@ Fri May 23 21:19:31 CEST 2003  Jan Hubicka  <jh@suse.cz>
 
 2003-05-21  Danny Smith  <dannysmith@users.sourceforge.net>
 
-       * gthr-win32.h (__GTHREAD_HIDE_WIN32API): Test for non-zero
+       * gthr-win32.h (__GTHREAD_HIDE_WIN32API): Test for nonzero
        value, not just if defined.
        Update copyright year.
 
@@ -5060,7 +5088,7 @@ Mon May 12 11:32:53 CEST 2003  Jan Hubicka  <jh@suse.cz>
                %call* relocs if generating explicit-reloc PIC.  Don't generate
                an exception_receiver pattern.
                (override_options): Initialize mips_got_alias_set.
-               (print_relocation): Remove in favour of...
+               (print_relocation): Remove in favor of...
                (mips_reloc_string): ...this new function.
                (print_operand): Handle '%R'.  Use mips_reloc_string.
                (print_operand_address): Use print_operand to print the symbolic
@@ -6459,7 +6487,7 @@ Sat Apr 19 14:56:17 CEST 2003  Jan Hubicka  <jh@suse.cz>
 2003-04-19  Nathan Sidwell  <nathan@codesourcery.com>
 
        * doc/invoke.texi (-fprofile-arcs): Mention -lgcov, locking and
-       fork behaviour.
+       fork behavior.
 
 2003-04-19  Neil Booth  <neil@daikokuya.co.uk>
 
@@ -7921,7 +7949,7 @@ Tue Apr  8 11:12:07 CEST 2003  Jan Hubicka  <jh@suse.cz>
 
        PR c/9516
        * expr.c (safe_from_p): Rearrange to avoid deep recursion in
-       favour of looping and tail recursion for TREE_LIST and binops.
+       favor of looping and tail recursion for TREE_LIST and binops.
 
 2003-04-08  Zdenek Dvorak  <rakdver@atrey.karlin.mff.cuni.cz>
 
@@ -11463,7 +11491,7 @@ Mon Mar 24 20:03:03 CET 2003  Jan Hubicka  <jh@suse.cz>
 
        * function.c (STACK_ALIGNMENT_NEEDED): New macro.  Default to 1.
        (assign_stack_local_1): Perform overall stack alignment only when
-       STACK_ALIGNMENT_NEEDED is non-zero.
+       STACK_ALIGNMENT_NEEDED is nonzero.
        * doc/tm.texi (STACK_ALIGNMENT_NEEDED): Document.
 
        * pa.c (compute_frame_size): Rename fsize to size.  Account for
index 7a624fb..39b4f3a 100644 (file)
@@ -4782,7 +4782,7 @@ Tue Oct 19 15:26:11 1999  Richard Earnshaw  (rearnsha@arm.com)
 Tue Oct 19 14:01:34 1999  Nick Clifton  <nickc@cygnus.com>
 
        * toplev.c (main): Do not generate an error message if an
-       unrecognized command line switch is recognisable by another
+       unrecognized command line switch is recognizable by another
        language.  If extra_warnings are enabled, then generate a
        warning message instead.
 
@@ -10733,7 +10733,7 @@ Thu Aug 19 11:51:22 EDT 1999  John Wehle  (john@feith.com)
 Thu Aug 19 15:02:01 1999  Nick Clifton  <nickc@cygnus.com>
 
        * config/rs6000/rs6000.c (rs6000_override_options): Fix test for
-       unrecognisable switches.
+       unrecognizable switches.
 
 Wed Aug 18 23:31:57 1999  J"orn Rennecke <amylaar@cygnus.co.uk>
 
index b81ecd8..ae921d0 100644 (file)
@@ -1793,7 +1793,7 @@ pushdecl (x)
 }
 
 /* Record X as belonging to the global scope (C99 "file scope").
-   This is used only internally by the Objective C front end,
+   This is used only internally by the Objective-C front end,
    and is limited to its needs.  It will hork if there is _any_
    visible binding for X (not just a global one).  */
 tree
index c5db914..0f6b045 100644 (file)
@@ -144,7 +144,7 @@ struct loop
   /* Loop that is copy of this loop.  */
   struct loop *copy;
 
-  /* Non-zero if the loop is invalid (e.g., contains setjmp.).  */
+  /* Nonzero if the loop is invalid (e.g., contains setjmp.).  */
   int invalid;
 
   /* Auxiliary info specific to a pass.  */
@@ -153,10 +153,10 @@ struct loop
   /* The following are currently used by loop.c but they are likely to
      disappear as loop.c is converted to use the CFG.  */
 
-  /* Non-zero if the loop has a NOTE_INSN_LOOP_VTOP.  */
+  /* Nonzero if the loop has a NOTE_INSN_LOOP_VTOP.  */
   rtx vtop;
 
-  /* Non-zero if the loop has a NOTE_INSN_LOOP_CONT.
+  /* Nonzero if the loop has a NOTE_INSN_LOOP_CONT.
      A continue statement will generate a branch to NEXT_INSN (cont).  */
   rtx cont;
 
index fd638bc..fd77f66 100644 (file)
@@ -71,7 +71,7 @@ hash_node (p)
                       (((struct cgraph_node *) p)->decl));
 }
 
-/* Returns non-zero if P1 and P2 are equal.  */
+/* Returns nonzero if P1 and P2 are equal.  */
 
 static int
 eq_node (p1, p2)
index 1b537c6..9f33b81 100644 (file)
@@ -340,7 +340,7 @@ get_coverage_counts (unsigned counter, unsigned expected,
   return entry->counts;
 }
 
-/* Allocate NUM counters of type COUNTER. Returns non-zero if the
+/* Allocate NUM counters of type COUNTER. Returns nonzero if the
    allocation succeeded.  */
 
 int
@@ -426,7 +426,7 @@ compute_checksum ()
 \f
 /* Begin output to the graph file for the current function.
    Opens the output file, if not already done. Writes the
-   function header, if not already done. Returns non-zero if data
+   function header, if not already done. Returns nonzero if data
    should be output.  */
 
 int
index 23a4476..b11e642 100644 (file)
@@ -42,7 +42,7 @@ static int ucn_valid_in_identifier PARAMS ((cpp_reader *, cppchar_t));
    are not part of the relevant standard, or if the string beginning
    at *PSTR doesn't syntactically match the form 'NNNN' or 'NNNNNNNN'.
 
-   Otherwise the non-zero value of the UCN, whether valid or invalid,
+   Otherwise the nonzero value of the UCN, whether valid or invalid,
    is returned.  Diagnostics are emitted for invalid values.  PSTR
    is updated to point one beyond the UCN, or to the syntactically
    invalid character.
index 88addea..f6dbb10 100644 (file)
@@ -343,7 +343,7 @@ struct cpp_reader
   struct cpp_path *quote_include;      /* "" */
   struct cpp_path *bracket_include;    /* <> */
 
-  /* Multiple include optimisation.  */
+  /* Multiple include optimization.  */
   const cpp_hashnode *mi_cmacro;
   const cpp_hashnode *mi_ind_cmacro;
   bool mi_valid;
index e072f01..72a5e4d 100644 (file)
@@ -192,7 +192,7 @@ warn_in_comment (pfile, note)
 
   /* Within comments we don't warn about trigraphs, unless the
      trigraph forms an escaped newline, as that may change
-     behaviour.  */
+     behavior.  */
   if (note->type != '/')
     return false;
 
@@ -710,7 +710,7 @@ _cpp_lex_token (pfile)
 
       /* Outside a directive, invalidate controlling macros.  At file
         EOF, _cpp_lex_direct takes care of popping the buffer, so we never
-        get here and MI optimisation works.  */
+        get here and MI optimization works.  */
       pfile->mi_valid = false;
 
       if (!pfile->state.skipping || result->type == CPP_EOF)
index 271aa5d..bd69642 100644 (file)
@@ -1490,7 +1490,7 @@ do_ifndef (pfile)
 
 /* _cpp_parse_expr puts a macro in a "#if !defined ()" expression in
    pfile->mi_ind_cmacro so we can handle multiple-include
-   optimisations.  If macro expansion occurs in the expression, we
+   optimizations.  If macro expansion occurs in the expression, we
    cannot treat it as a controlling conditional, since the expansion
    could change in the future.  That is handled by cpp_get_token.  */
 static void
index 7b13e3b..baf473b 100644 (file)
@@ -1804,7 +1804,7 @@ dbxout_type (type, full)
     }
 }
 
-/* Return non-zero if the given type represents an integer whose bounds
+/* Return nonzero if the given type represents an integer whose bounds
    should be printed in octal format.  */
 
 static bool
index b23c286..25396bd 100644 (file)
--- a/gcc/ggc.h
+++ b/gcc/ggc.h
@@ -103,7 +103,7 @@ extern const struct ggc_cache_tab * const gt_ggc_cache_rtab[];
 
 /* Actually set the mark on a particular region of memory, but don't
    follow pointers.  This function is called by ggc_mark_*.  It
-   returns zero if the object was not previously marked; non-zero if
+   returns zero if the object was not previously marked; nonzero if
    the object was already marked, or if, for any other reason,
    pointers in this data structure should not be traversed.  */
 extern int ggc_set_mark        (const void *);
index 25dacf2..83561b2 100644 (file)
@@ -163,7 +163,7 @@ handle_option (int argc ATTRIBUTE_UNUSED, char **argv, int lang_mask)
       if (!on && (option->flags & CL_REJECT_NEGATIVE))
        goto done;
 
-      /* We've recognised this switch.  */
+      /* We've recognized this switch.  */
       result = 1;
 
       /* Sort out any argument the switch takes.  */
index 4a4b040..4e1dc22 100644 (file)
@@ -2281,7 +2281,7 @@ real_nan (r, str, quiet, mode)
 }
 
 /* Fills R with the largest finite value representable in mode MODE.
-   If SIGN is non-zero, R is set to the most negative finite value.  */
+   If SIGN is nonzero, R is set to the most negative finite value.  */
 
 void
 real_maxval (r, sign, mode)
@@ -3033,7 +3033,7 @@ const struct real_format mips_double_format =
 
 \f
 /* IEEE extended double precision format.  This comes in three
-   flavours: Intel's as a 12 byte image, Intel's as a 16 byte image,
+   flavors: Intel's as a 12 byte image, Intel's as a 16 byte image,
    and Motorola's.  */
 
 static void encode_ieee_extended PARAMS ((const struct real_format *fmt,
index 5a82d99..7ab823d 100644 (file)
@@ -4887,7 +4887,7 @@ find_reloads_address (mode, memrefloc, ad, loc, opnum, type, ind_levels, insn)
      of it.
 
      Handle all base registers here, not just fp/ap/sp, because on some
-     targets (namely Sparc) we can also get invalid addresses from preventive
+     targets (namely SPARC) we can also get invalid addresses from preventive
      subreg big-endian corrections made by find_reloads_toplev.
 
      If we decide to do something, it must be that `double_reg_address_ok'
index 4561d72..1bf70f8 100644 (file)
@@ -5592,7 +5592,7 @@ expand_end_case_type (orig_index, orig_type)
              /* For constant index expressions we need only
                 issue an unconditional branch to the appropriate
                 target code.  The job of removing any unreachable
-                code is left to the optimisation phase if the
+                code is left to the optimization phase if the
                 "-O" option is specified.  */
              for (n = thiscase->data.case_stmt.case_list; n; n = n->right)
                if (! tree_int_cst_lt (index_expr, n->low)
--- a/gcc/df.c
+++ b/gcc/df.c
@@ -149,7 +149,7 @@ Similarly, should the first entry in the use list be the last use
 4) Working with a sub-CFG.
 
 Often the whole CFG does not need to be analyzed, for example,
-when optimising a loop, only certain registers are of interest.
+when optimizing a loop, only certain registers are of interest.
 Perhaps there should be a bitmap argument to df_analyse to specify
 which registers should be analyzed?
 
@@ -885,7 +885,7 @@ df_ref_record (df, reg, loc, insn, ref_type, ref_flags)
 }
 
 
/* Return non-zero if writes to paradoxical SUBREGs, or SUBREGs which
    are too narrow, are read-modify-write.  */
 bool
 read_modify_subreg_p (x)
index dd0ee35..62528b8 100644 (file)
@@ -11291,7 +11291,7 @@ gen_label_die (decl, context_die)
       insn = DECL_RTL (decl);
 
       /* Deleted labels are programmer specified labels which have been
-        eliminated because of various optimisations.  We still emit them
+        eliminated because of various optimizations.  We still emit them
         here so that it is possible to put breakpoints on them.  */
       if (GET_CODE (insn) == CODE_LABEL
          || ((GET_CODE (insn) == NOTE
index 8555443..663bb9f 100644 (file)
@@ -3948,7 +3948,7 @@ output_label_die (arg)
       rtx insn = DECL_RTL (decl);
 
       /* Deleted labels are programmer specified labels which have been
-        eliminated because of various optimisations.  We still emit them
+        eliminated because of various optimizations.  We still emit them
         here so that it is possible to put breakpoints on them.  */
       if (GET_CODE (insn) == CODE_LABEL
          || ((GET_CODE (insn) == NOTE
@@ -5741,7 +5741,7 @@ dwarfout_file_scope_decl (decl, set_finalizing)
         normal built-in types for the language we are compiling, except
         in cases where the types in question are *not* DWARF fundamental
         types.  We make an exception in the case of non-fundamental types
-        for the sake of objective C (and perhaps C++) because the GNU
+        for the sake of Objective-C (and perhaps C++) because the GNU
         front-ends for these languages may in fact create certain "built-in"
         types which are (for example) RECORD_TYPEs.  In such cases, we
         really need to output these (non-fundamental) types because other
index 208af57..03ee0ca 100644 (file)
@@ -351,7 +351,7 @@ reg_attrs_htab_hash (x)
   return ((p->offset * 1000) ^ (long) p->decl);
 }
 
/* Returns non-zero if the value represented by X (which is really a
    reg_attrs *) is the same as that given by Y (which is also really a
    reg_attrs *).  */
 
index ec7a69a..cd0a158 100644 (file)
@@ -663,7 +663,7 @@ maybe_set_unchanging (ref, t)
      contents of the initializer.  Yes, this does eliminate a good fraction
      of the number of uses of RTX_UNCHANGING_P for a language like Ada.
      It also eliminates a good quantity of bugs.  Let this be incentive to
-     eliminate RTX_UNCHANGING_P entirely in favour of a more reliable
+     eliminate RTX_UNCHANGING_P entirely in favor of a more reliable
      solution, perhaps based on alias sets.  */
 
   if ((TREE_READONLY (t) && DECL_P (t)
index 94197c9..112e77c 100644 (file)
@@ -313,7 +313,7 @@ gcov_write_tag_length (gcov_unsigned_t tag, gcov_unsigned_t length)
   return;
 }
 
/* Write a summary structure to the gcov file.  Return non-zero on
    overflow.  */
 
 GCOV_LINKAGE void
@@ -489,7 +489,7 @@ gcov_sync (gcov_position_t base, gcov_unsigned_t length)
 
 #if IN_LIBGCOV
 /* Move to the a set position in a gcov file.  BASE is zero to move to
-   the end, and non-zero to move to that position. */
+   the end, and nonzero to move to that position. */
 
 GCOV_LINKAGE void
 gcov_seek (gcov_position_t base)
index e6cf94e..e512783 100644 (file)
@@ -147,8 +147,8 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 
    This file is included by both the compiler, gcov tools and the
    runtime support library libgcov. IN_LIBGCOV and IN_GCOV are used to
-   distinguish which case is which.  If IN_LIBGCOV is non-zero,
-   libgcov is being built. If IN_GCOV is non-zero, the gcov tools are
+   distinguish which case is which.  If IN_LIBGCOV is nonzero,
+   libgcov is being built. If IN_GCOV is nonzero, the gcov tools are
    being built. Otherwise the compiler is being built. IN_GCOV may be
    positive or negative. If positive, we are compiling a tool that
    requires additional functions (see the code for knowledge of what
@@ -480,7 +480,7 @@ gcov_position (void)
   return gcov_var.start + gcov_var.offset;
 }
 
/* Return non-zero if we read to end of file.  */
 
 static inline int
 gcov_is_eof ()
@@ -488,7 +488,7 @@ gcov_is_eof ()
   return !gcov_var.overread;
 }
 
/* Return non-zero if the error flag is set.  */
 
 static inline int
 gcov_is_error ()
index 4c92170..fd18c00 100644 (file)
@@ -1745,7 +1745,7 @@ accumulate_line_counts (src)
     }
 }
 
/* Ouput information about ARC number IX.  Returns non-zero if
    anything is output.  */
 
 static int
index 52e8780..0e58dc0 100644 (file)
@@ -1654,7 +1654,7 @@ walk_type (type_p t, struct walk_type_data *d)
        const char *oldval = d->val;
        char *newval;
 
-       /* If it's an array of scalars, we optimise by not generating
+       /* If it's an array of scalars, we optimize by not generating
           any code.  */
        if (t->u.a.p->kind == TYPE_SCALAR)
          break;
@@ -885,7 +885,7 @@ df_ref_record (df, reg, loc, insn, ref_type, ref_flags)
 
 
-/* Return non-zero if writes to paradoxical SUBREGs, or SUBREGs which
+/* Return nonzero if writes to paradoxical SUBREGs, or SUBREGs which
    are too narrow, are read-modify-write.  */
 bool
@@ -351,7 +351,7 @@ reg_attrs_htab_hash (x)
 }
 
-/* Returns non-zero if the value represented by X (which is really a
+/* Returns nonzero if the value represented by X (which is really a
    reg_attrs *) is the same as that given by Y (which is also really a
    reg_attrs *).  */
@@ -313,7 +313,7 @@ gcov_write_tag_length (gcov_unsigned_t tag, gcov_unsigned_t length)
 }
 
-/* Write a summary structure to the gcov file.  Return non-zero on
+/* Write a summary structure to the gcov file.  Return nonzero on
    overflow.  */
 
@@ -480,7 +480,7 @@ gcov_position (void)
 }
 
-/* Return non-zero if we read to end of file.  */
+/* Return nonzero if we read to end of file.  */
 
 static inline int
@@ -488,7 +488,7 @@ gcov_is_eof ()
 }
 
-/* Return non-zero if the error flag is set.  */
+/* Return nonzero if the error flag is set.  */
 
 static inline int
@@ -1745,7 +1745,7 @@ accumulate_line_counts (src)
 }
 
-/* Ouput information about ARC number IX.  Returns non-zero if
+/* Ouput information about ARC number IX.  Returns nonzero if
    anything is output.  */
 
index 2f7d09c..e2a76e5 100644 (file)